@@ -60,8 +60,8 @@ EbmlMaster::EbmlMaster(const EbmlMaster & ElementToClone)
  ,Checksum(ElementToClone.Checksum)
 {
   // add a clone of the list
-  std::vector<EbmlElement *>::const_iterator Itr = ElementToClone.ElementList.begin();
-  std::vector<EbmlElement *>::iterator myItr = ElementList.begin();
+  auto Itr = ElementToClone.ElementList.begin();
+  auto myItr = ElementList.begin();
   while (Itr != ElementToClone.ElementList.end())
   {
     *myItr = (*Itr)->Clone();
@@ -74,11 +74,9 @@ EbmlMaster::~EbmlMaster()
 {
   assert(!IsLocked()); // you're trying to delete a locked element !!!
 
-  size_t Index;
-
-  for (Index = 0; Index < ElementList.size(); Index++) {
-    if (!(*ElementList[Index]).IsLocked())  {
-      delete ElementList[Index];
+  for (auto Element : ElementList) {
+    if (!Element->IsLocked())  {
+      delete Element;
     }
   }
 }
@@ -90,24 +88,23 @@ EbmlMaster::~EbmlMaster()
 filepos_t EbmlMaster::RenderData(IOCallback & output, bool bForceRender, bool bWithDefault)
 {
   filepos_t Result = 0;
-  size_t Index;
 
   if (!bForceRender) {
     assert(CheckMandatory());
   }
 
   if (!bChecksumUsed) { // old school
-    for (Index = 0; Index < ElementList.size(); Index++) {
-      if (!bWithDefault && (ElementList[Index])->IsDefaultValue())
+    for (auto Element : ElementList) {
+      if (!bWithDefault && Element->IsDefaultValue())
         continue;
-      Result += (ElementList[Index])->Render(output, bWithDefault, false ,bForceRender);
+      Result += Element->Render(output, bWithDefault, false ,bForceRender);
     }
   } else { // new school
     MemIOCallback TmpBuf(GetSize() - 6);
-    for (Index = 0; Index < ElementList.size(); Index++) {
-      if (!bWithDefault && (ElementList[Index])->IsDefaultValue())
+    for (auto Element : ElementList) {
+      if (!bWithDefault && Element->IsDefaultValue())
         continue;
-      (ElementList[Index])->Render(TmpBuf, bWithDefault, false ,bForceRender);
+      Element->Render(TmpBuf, bWithDefault, false ,bForceRender);
     }
     Checksum.FillCRC32(TmpBuf.GetDataBuffer(), TmpBuf.GetDataBufferSize());
     Result += Checksum.Render(output, true, false ,bForceRender);
@@ -138,13 +135,11 @@ uint64 EbmlMaster::UpdateSize(bool bWithDefault, bool bForceRender)
     assert(CheckMandatory());
     }
 
-  size_t Index;
-
-  for (Index = 0; Index < ElementList.size(); Index++) {
-    if (!bWithDefault && (ElementList[Index])->IsDefaultValue())
+  for (auto Element : ElementList) {
+    if (!bWithDefault && Element->IsDefaultValue())
       continue;
-    (ElementList[Index])->UpdateSize(bWithDefault, bForceRender);
-    uint64 SizeToAdd = (ElementList[Index])->ElementSize(bWithDefault);
+    Element->UpdateSize(bWithDefault, bForceRender);
+    uint64 SizeToAdd = Element->ElementSize(bWithDefault);
 #if defined(LIBEBML_DEBUG)
     if (static_cast<int64>(SizeToAdd) == (0-1))
       return (0-1);
@@ -203,7 +198,7 @@ bool EbmlMaster::CheckMandatory() const
   unsigned int EltIdx;
   for (EltIdx = 0; EltIdx < EBML_CTX_SIZE(Context); EltIdx++) {
     if (EBML_CTX_IDX(Context,EltIdx).IsMandatory()) {
-      if (FindElt(EBML_CTX_IDX_INFO(Context,EltIdx)) == NULL) {
+      if (FindElt(EBML_CTX_IDX_INFO(Context,EltIdx)) == nullptr) {
         EbmlElement *testElement = &EBML_CTX_IDX(Context,EltIdx).Create();
         bool hasDefaultValue     = testElement->DefaultISset();
         delete testElement;
@@ -227,8 +222,7 @@ std::vector<std::string> EbmlMaster::FindAllMissingElements()
 
   std::vector<std::string> missingElements;
 
-  for (size_t ChildElementNo = 0; ChildElementNo < ElementList.size(); ChildElementNo++) {
-       EbmlElement *childElement = ElementList[ChildElementNo];
+  for (auto childElement : ElementList) {
     if (!childElement->ValueIsSet()) {
       std::string missingValue;
       missingValue = "The Child Element \"";
@@ -240,22 +234,21 @@ std::vector<std::string> EbmlMaster::FindAllMissingElements()
     }
 
     if (childElement->IsMaster()) {
-      EbmlMaster *childMaster = (EbmlMaster *)childElement;
+      auto childMaster = reinterpret_cast<EbmlMaster *>(childElement);
 
       std::vector<std::string> childMissingElements = childMaster->FindAllMissingElements();
-      for (size_t s = 0; s < childMissingElements.size(); s++)
-        missingElements.push_back(childMissingElements[s]);
+      std::copy(childMissingElements.begin(), childMissingElements.end(), std::back_inserter(missingElements));
     }
   }
   unsigned int EltIdx;
   for (EltIdx = 0; EltIdx < EBML_CTX_SIZE(Context); EltIdx++) {
     if (EBML_CTX_IDX(Context,EltIdx).IsMandatory()) {
-      if (FindElt(EBML_CTX_IDX_INFO(Context,EltIdx)) == NULL) {
+      if (FindElt(EBML_CTX_IDX_INFO(Context,EltIdx)) == nullptr) {
         std::string missingElement;
         missingElement = "Missing element \"";
-                missingElement.append(EBML_INFO_NAME(EBML_CTX_IDX_INFO(Context,EltIdx)));
+        missingElement.append(EBML_INFO_NAME(EBML_CTX_IDX_INFO(Context,EltIdx)));
         missingElement.append("\" in EbmlMaster \"");
-                missingElement.append(EBML_INFO_NAME(*EBML_CTX_MASTER(Context)));
+        missingElement.append(EBML_INFO_NAME(*EBML_CTX_MASTER(Context)));
         missingElement.append("\"");
         missingElements.push_back(missingElement);
       }
@@ -267,52 +260,42 @@ std::vector<std::string> EbmlMaster::FindAllMissingElements()
 
 EbmlElement *EbmlMaster::FindElt(const EbmlCallbacks & Callbacks) const
 {
-  size_t Index;
+  auto it = std::find_if(ElementList.begin(), ElementList.end(), [&](const EbmlElement *Element)
+    { return EbmlId(*Element) == EBML_INFO_ID(Callbacks); });
 
-  for (Index = 0; Index < ElementList.size(); Index++) {
-    EbmlElement * tmp = ElementList[Index];
-    if (EbmlId(*tmp) == EBML_INFO_ID(Callbacks))
-      return tmp;
-  }
-
-  return NULL;
+  return it != ElementList.end() ? *it : nullptr;
 }
 
 EbmlElement *EbmlMaster::FindFirstElt(const EbmlCallbacks & Callbacks, bool bCreateIfNull)
 {
-  size_t Index;
+  auto it = std::find_if(ElementList.begin(), ElementList.end(), [&](const EbmlElement *Element)
+    { return Element && EbmlId(*Element) == EBML_INFO_ID(Callbacks); });
 
-  for (Index = 0; Index < ElementList.size(); Index++) {
-    if (ElementList[Index] && EbmlId(*(ElementList[Index])) == EBML_INFO_ID(Callbacks))
-      return ElementList[Index];
-  }
+  if (it != ElementList.end())
+    return *it;
 
   if (bCreateIfNull) {
     // add the element
     EbmlElement *NewElt = &EBML_INFO_CREATE(Callbacks);
-    if (NewElt == NULL)
-      return NULL;
+    if (NewElt == nullptr)
+      return nullptr;
 
     if (!PushElement(*NewElt)) {
       delete NewElt;
-      NewElt = NULL;
+      NewElt = nullptr;
     }
     return NewElt;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 EbmlElement *EbmlMaster::FindFirstElt(const EbmlCallbacks & Callbacks) const
 {
-  size_t Index;
+  auto it = std::find_if(ElementList.begin(), ElementList.end(), [&](const EbmlElement *Element)
+    { return EbmlId(*Element) == EBML_INFO_ID(Callbacks); });
 
-  for (Index = 0; Index < ElementList.size(); Index++) {
-    if (EbmlId(*(ElementList[Index])) == EBML_INFO_ID(Callbacks))
-      return ElementList[Index];
-  }
-
-  return NULL;
+  return it != ElementList.end() ? *it : nullptr;
 }
 
 /*!
@@ -321,39 +304,30 @@ EbmlElement *EbmlMaster::FindFirstElt(const EbmlCallbacks & Callbacks) const
 */
 EbmlElement *EbmlMaster::FindNextElt(const EbmlElement & PastElt, bool bCreateIfNull)
 {
-  size_t Index;
+  auto it = std::find(ElementList.begin(), ElementList.end(), &PastElt);
+  if (it != ElementList.end()) {
+    it = std::find_if(it + 1, ElementList.end(), [&](auto &&element) {
+      return EbmlId(PastElt) == EbmlId(*element);
+    });
 
-  for (Index = 0; Index < ElementList.size(); Index++) {
-    if ((ElementList[Index]) == &PastElt) {
-      // found past element, new one is :
-      Index++;
-      break;
-    }
+    if (it != ElementList.end())
+      return *it;
   }
 
-  while (Index < ElementList.size()) {
-    if ((EbmlId)PastElt == (EbmlId)(*ElementList[Index]))
-      break;
-    Index++;
-  }
-
-  if (Index != ElementList.size())
-    return ElementList[Index];
-
   if (bCreateIfNull) {
     // add the element
     EbmlElement *NewElt = &(PastElt.CreateElement());
-    if (NewElt == NULL)
-      return NULL;
+    if (NewElt == nullptr)
+      return nullptr;
 
     if (!PushElement(*NewElt)) {
       delete NewElt;
-      NewElt = NULL;
+      NewElt = nullptr;
     }
     return NewElt;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 EbmlElement *EbmlMaster::FindNextElt(const EbmlElement & PastElt) const
@@ -369,24 +343,24 @@ EbmlElement *EbmlMaster::FindNextElt(const EbmlElement & PastElt) const
   }
 
   while (Index < ElementList.size()) {
-    if ((EbmlId)PastElt == (EbmlId)(*ElementList[Index]))
+    if (EbmlId(PastElt) == EbmlId(*ElementList[Index]))
       return ElementList[Index];
     Index++;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 EbmlElement *EbmlMaster::AddNewElt(const EbmlCallbacks & Callbacks)
 {
   // add the element
   EbmlElement *NewElt = &EBML_INFO_CREATE(Callbacks);
-  if (NewElt == NULL)
-    return NULL;
+  if (NewElt == nullptr)
+    return nullptr;
 
   if (!PushElement(*NewElt)) {
     delete NewElt;
-    NewElt = NULL;
+    NewElt = nullptr;
   }
   return NewElt;
 }
@@ -408,10 +382,9 @@ void EbmlMaster::Read(EbmlStream & inDataStream, const EbmlSemanticContext & sCo
 
   EbmlElement * ElementLevelA;
   // remove all existing elements, including the mandatory ones...
-  size_t Index;
-  for (Index=0; Index<ElementList.size(); Index++) {
-    if (!(*ElementList[Index]).IsLocked()) {
-      delete ElementList[Index];
+  for (auto Element : ElementList) {
+    if (!Element->IsLocked()) {
+        delete Element;
     }
   }
   ElementList.clear();
@@ -427,7 +400,7 @@ void EbmlMaster::Read(EbmlStream & inDataStream, const EbmlSemanticContext & sCo
   {
     inDataStream.I_O().setFilePointer(GetSizePosition() + GetSizeLength(), seek_beginning);
     ElementLevelA = inDataStream.FindNextElement(sContext, UpperEltFound, MaxSizeToRead, AllowDummyElt);
-    while (ElementLevelA != NULL && UpperEltFound <= 0 && MaxSizeToRead > 0) {
+    while (ElementLevelA != nullptr && UpperEltFound <= 0 && MaxSizeToRead > 0) {
       if (IsFiniteSize() && ElementLevelA->IsFiniteSize())
         MaxSizeToRead = GetEndPosition() - ElementLevelA->GetEndPosition(); // even if it's the default value
       if (!AllowDummyElt && ElementLevelA->IsDummy()) {
@@ -439,7 +412,16 @@ void EbmlMaster::Read(EbmlStream & inDataStream, const EbmlSemanticContext & sCo
           break;
         }
       } else {
-        ElementLevelA->Read(inDataStream, EBML_CONTEXT(ElementLevelA), UpperEltFound, FoundElt, AllowDummyElt, ReadFully);
+        try {
+          ElementLevelA->Read(inDataStream, EBML_CONTEXT(ElementLevelA), UpperEltFound, FoundElt, AllowDummyElt, ReadFully);
+        } catch (...) {
+          if (ElementLevelA == FoundElt) {
+            UpperEltFound = 0;
+            FoundElt = nullptr;
+          }
+          delete ElementLevelA;
+          throw;
+        }
 
         // Discard elements that couldn't be read properly if
         // SCOPE_ALL_DATA has been requested. This can happen
@@ -498,7 +480,7 @@ processCrc:
 
   EBML_MASTER_ITERATOR Itr, CrcItr;
   for (Itr = ElementList.begin(); Itr != ElementList.end();) {
-    if ((EbmlId)(*(*Itr)) == EBML_ID(EbmlCrc32)) {
+    if (EbmlId(*(*Itr)) == EBML_ID(EbmlCrc32)) {
       bChecksumUsed = true;
       // remove the element
       Checksum = *(static_cast<EbmlCrc32*>(*Itr));
@@ -520,7 +502,7 @@ processCrc:
 void EbmlMaster::Remove(size_t Index)
 {
   if (Index < ElementList.size()) {
-    std::vector<EbmlElement *>::iterator Itr = ElementList.begin();
+    auto Itr = ElementList.begin();
     while (Index-- > 0) {
       ++Itr;
     }
@@ -548,8 +530,8 @@ bool EbmlMaster::VerifyChecksum() const
   /// \todo remove the Checksum if it's in the list
   /// \todo find another way when not all default values are saved or (unknown from the reader !!!)
   MemIOCallback TmpBuf(GetSize() - 6);
-  for (size_t Index = 0; Index < ElementList.size(); Index++) {
-    (ElementList[Index])->Render(TmpBuf, true, false, true);
+  for (auto Element : ElementList) {
+    Element->Render(TmpBuf, true, false, true);
   }
   aChecksum.FillCRC32(TmpBuf.GetDataBuffer(), TmpBuf.GetDataBufferSize());
   return (aChecksum.GetCrc32() == Checksum.GetCrc32());
@@ -557,7 +539,7 @@ bool EbmlMaster::VerifyChecksum() const
 
 bool EbmlMaster::InsertElement(EbmlElement & element, size_t position)
 {
-  std::vector<EbmlElement *>::iterator Itr = ElementList.begin();
+  auto Itr = ElementList.begin();
   while (Itr != ElementList.end() && position--)
   {
     ++Itr;
@@ -571,7 +553,7 @@ bool EbmlMaster::InsertElement(EbmlElement & element, size_t position)
 
 bool EbmlMaster::InsertElement(EbmlElement & element, const EbmlElement & before)
 {
-  std::vector<EbmlElement *>::iterator Itr = ElementList.begin();
+  auto Itr = ElementList.begin();
   while (Itr != ElementList.end() && *Itr != &before)
   {
     ++Itr;
