@@ -23,4 +23,7 @@ std::string primary_file_extension_for_type(std::string const &type_name);
 
 std::vector<std::string> sorted_type_names();
 
+const std::unordered_map<std::string, std::string> &legacy_font_mime_type_mapping();
+std::string maybe_map_to_legacy_font_mime_type(std::string const &mime_type, bool do_map);
+
 }
