@@ -109,18 +109,26 @@ open_playlist_file(filelist_t &file,
 static debugging_option_c s_debug_probe{"probe_file_format"};
 
 template<typename Treader>
-typename std::enable_if<
-  std::is_base_of<generic_reader_c, Treader>::value,
-  std::unique_ptr<generic_reader_c>
->::type
-do_probe(mm_io_cptr const &io,
-         probe_range_info_t const &probe_range_info = {}) {
+std::unique_ptr<Treader>
+create_and_prepare_reader(mm_io_cptr const &io,
+                          probe_range_info_t const &probe_range_info = {}) {
   auto reader = std::make_unique<Treader>();
 
   io->setFilePointer(0);
   reader->set_file_to_read(io);
   reader->set_probe_range_info(probe_range_info);
 
+  return reader;
+}
+
+template<typename Treader>
+typename std::enable_if<
+  std::is_base_of<generic_reader_c, Treader>::value,
+  std::unique_ptr<generic_reader_c>
+>::type
+do_probe(mm_io_cptr const &io,
+         probe_range_info_t const &probe_range_info = {}) {
+  auto reader    = create_and_prepare_reader<Treader>(io, probe_range_info);
   auto probed_ok = false;
 
   try {
@@ -217,6 +225,16 @@ detect_text_file_formats(filelist_t const &file) {
     // Unsupported text subtitle formats
     do_probe<microdvd_reader_c>(text_io);
 
+    // Support empty files for certain types.
+    if ((text_io->get_size() - text_io->get_byte_order_length()) > 1)
+      return {};
+
+    auto extension = mtx::fs::to_path(file.name).extension().u8string().substr(1);
+
+    for (auto type : mtx::file_type_t::by_extension(extension))
+      if (type == mtx::file_type_e::srt)
+        return create_and_prepare_reader<srt_reader_c>(text_io);
+
   } catch (mtx::mm_io::exception &ex) {
     mxerror(fmt::format(Y("The file '{0}' could not be opened for reading: {1}.\n"), file.name, ex));
 
@@ -294,6 +312,13 @@ probe_file_format(filelist_t &file) {
   if ((reader = detect_text_file_formats(file)))
     return reader;
 
+  // AVC & HEVC, even though often mis-detected, have a very high
+  // probability of correct detection with headers right at the start.
+  if ((reader = do_probe<avc_es_reader_c>(io, { 0, 0, true })))
+    return reader;
+  if ((reader = do_probe<hevc_es_reader_c>(io, { 0, 0, true })))
+    return reader;
+
   // Try raw audio formats and require eight consecutive frames at the
   // start of the file.
   if ((reader = do_probe<mp3_reader_c>(io, { 128 * 1024, 8, true })))
@@ -348,9 +373,9 @@ probe_file_format(filelist_t &file) {
 
   if ((reader = do_probe<mpeg_es_reader_c>(io)))
     return reader;
-  if ((reader = do_probe<avc_es_reader_c>(io)))
+  if ((reader = do_probe<avc_es_reader_c>(io, { 0, 0, false })))
     return reader;
-  if ((reader = do_probe<hevc_es_reader_c>(io)))
+  if ((reader = do_probe<hevc_es_reader_c>(io, { 0, 0, false })))
     return reader;
 
   // File types which are the same in raw format and in other container formats.
