@@ -185,11 +185,19 @@ Tool::openFilesFromCommandLine(QStringList const &fileNames) {
 
 void
 Tool::selectFileToOpen(bool append) {
+  QString dvds, ifo;
+
+#if defined(HAVE_DVDREAD)
+  dvds = QY("DVDs") + Q(" (*.ifo *.IFO);;");
+  ifo  = Q(" *.ifo *.IFO");
+#endif  // HAVE_DVDREAD
+
   auto fileNames = Util::getOpenFileNames(this, append ? QY("Append files in chapter editor") : QY("Open files in chapter editor"), Util::Settings::get().lastOpenDirPath(),
-                                          QY("Supported file types")           + Q(" (*.cue *.mpls *.mkv *.mka *.mks *.mk3d *.txt *.webm *.xml);;") +
+                                          QY("Supported file types")           + Q(" (*.cue%1 *.mpls *.mkv *.mka *.mks *.mk3d *.txt *.webm *.xml);;").arg(ifo) +
                                           QY("Matroska files")                 + Q(" (*.mkv *.mka *.mks *.mk3d);;") +
                                           QY("WebM files")                     + Q(" (*.webm);;") +
                                           QY("Blu-ray playlist files")         + Q(" (*.mpls);;") +
+                                          dvds +
                                           QY("XML chapter files")              + Q(" (*.xml);;") +
                                           QY("Simple OGM-style chapter files") + Q(" (*.txt);;") +
                                           QY("Cue sheet files")                + Q(" (*.cue);;") +
@@ -351,7 +359,7 @@ Tool::removeChaptersFromExistingMatroskaFile() {
   if (fileName.isEmpty())
     return;
 
-  auto analyzer = std::make_unique<QtKaxAnalyzer>(this, fileName);
+  auto analyzer = std::make_unique<Util::KaxAnalyzer>(this, fileName);
 
   if (!analyzer->set_parse_mode(kax_analyzer_c::parse_mode_fast).process()) {
     auto text = Q("%1 %2")
@@ -370,7 +378,7 @@ Tool::removeChaptersFromExistingMatroskaFile() {
   auto result = analyzer->remove_elements(EBML_ID(libmatroska::KaxChapters));
 
   if (kax_analyzer_c::uer_success != result) {
-    QtKaxAnalyzer::displayUpdateElementResult(this, result, QY("Removing the chapters failed."));
+    Util::KaxAnalyzer::displayUpdateElementResult(this, result, QY("Removing the chapters failed."));
 
   } else
     Util::MessageBox::information(this)->title(QY("Removing chapters from existing Matroska file")).text(QY("All chapters have been removed from the file '%1'.").arg(fileName)).exec();
