@@ -1,11 +1,13 @@
 #include "common/common_pch.h"
 
-#if defined(SYS_LINUX)
+#if !defined(SYS_APPLE) && !defined(SYS_WINDOWS)
 
 #include <QDebug>
 #include <QProcess>
 
+#include "common/fs_sys_helpers.h"
 #include "common/list_utils.h"
+#include "common/path.h"
 #include "common/qt.h"
 #include "mkvtoolnix-gui/jobs/program_runner/linux_program_runner.h"
 
@@ -24,42 +26,40 @@ LinuxProgramRunner::isRunProgramTypeSupported(Util::Settings::RunProgramType typ
   if (ProgramRunner::isRunProgramTypeSupported(type))
     return true;
 
+  if (mtx::sys::find_exe_in_path(mtx::fs::to_path("systemctl")).empty())
+    return false;
+
   return mtx::included_in(type, Util::Settings::RunProgramType::ShutDownComputer, Util::Settings::RunProgramType::HibernateComputer, Util::Settings::RunProgramType::SleepComputer);
 }
 
 void
-LinuxProgramRunner::shutDownComputer(Util::Settings::RunProgramConfig &) {
-  qDebug() << "LinuxProgramRunner::shutDownComputer: about to shut down the computer via systemctl";
+LinuxProgramRunner::systemctlAction(QString const &action) {
+  qDebug() << Q("LinuxProgramRunner::systemctlAction: about to execute 'systemctl %1'").arg(action);
 
-  auto result = QProcess::execute("systemctl poweroff");
+  auto args   = QStringList{} << action;
+  auto result = QProcess::execute(Q("systemctl"), args);
 
   if (result == 0)
     return;
 
-  qDebug() << "LinuxProgramRunner::shutDownComputer: 'systemctl poweroff' failed:" << result;
+  qDebug() << Q("LinuxProgramRunner::systemctlAction: 'systemctl %1' failed: %2").arg(action).arg(result);
 }
 
 void
-LinuxProgramRunner::hibernateOrSleepComputer(bool hibernate) {
-  auto action = Q(hibernate ? "hibernate" : "suspend");
-  qDebug() << "LinuxProgramRunner::hibernateOrSleepComputer: about to" << action << "the computer via systemctl";
-
-  auto result = QProcess::execute(Q("systemctl %1").arg(action));
-
-  if (result != 0)
-    qDebug() << "LinuxProgramRunner::hibernateOrSleepComputer: 'systemctl" << action << "' failed:" << result;
+LinuxProgramRunner::shutDownComputer(Util::Settings::RunProgramConfig &) {
+  systemctlAction(Q("poweroff"));
 }
 
 void
 LinuxProgramRunner::hibernateComputer(Util::Settings::RunProgramConfig &) {
-  hibernateOrSleepComputer(true);
+  systemctlAction(Q("hibernate"));
 }
 
 void
 LinuxProgramRunner::sleepComputer(Util::Settings::RunProgramConfig &) {
-  hibernateOrSleepComputer(false);
+  systemctlAction(Q("suspend"));
 }
 
 }
 
-#endif  // SYS_LINUX
+#endif  // !SYS_APPLE && !SYS_WINDOWS
