@@ -19,6 +19,7 @@
 #include "mkvtoolnix-gui/main_window/preferences_dialog.h"
 #include "mkvtoolnix-gui/main_window/prefs_language_shortcut_dialog.h"
 #include "mkvtoolnix-gui/main_window/prefs_run_program_widget.h"
+#include "mkvtoolnix-gui/merge/adding_directories_dialog.h"
 #include "mkvtoolnix-gui/merge/additional_command_line_options_dialog.h"
 #include "mkvtoolnix-gui/merge/source_file.h"
 #include "mkvtoolnix-gui/util/container.h"
@@ -123,6 +124,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent,
   setupEnableMuxingTracksByType();
   setupEnableMuxingTracksByLanguage();
   setupMergeAddingAppendingFilesPolicy();
+  setupMergeAddingAppendingDirectoriesPolicy();
   setupMergeWarnMissingAudioTrack();
   setupMergePredefinedItems();
   setupTrackPropertiesLayout();
@@ -274,6 +276,9 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("By default the GUI will start up with a dark color scheme if the color scheme in Windows is set to dark mode."))
                    .arg(QY("If this option is enabled, the GUI will not use its dark mode and fall back to the default color scheme.")));
 
+
+  Util::setToolTip(ui->sbGuiNumRecentlyUsedStrings, QY("This affects functions such as the selector of recently used destination directories in the multiplexer."));
+
   Util::setToolTip(ui->cbGuiCheckForUpdates,
                    Q("%1 %2 %3")
                    .arg(QY("If enabled, the program will check online whether or not a new release of MKVToolNix is available on the home page."))
@@ -426,6 +431,16 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("The default is to always add all the files to the current multiplex settings."))
                    .arg(QY("The GUI can also ask the user what to do each time, e.g. appending them instead of adding them, or creating new multiplex settings and adding them to those.")));
 
+  QString fullText;
+
+  for (auto const &text : Merge::AddingDirectoriesDialog::optionDescriptions())
+    fullText += Q("<li>%1</li>").arg(text.toHtmlEscaped());
+
+  Util::setToolTip(ui->cbMDragAndDropDirectoriesPolicy,
+                   Q("<p>%1</p><ol>%2</ol>")
+                   .arg(QY("When the user drags & drops directories from an external application onto the multiplex tool the GUI can take different actions."))
+                   .arg(fullText));
+
   Util::setToolTip(ui->cbMWarnMissingAudioTrack, QY("The GUI can ask for confirmation when you're about to create a file without audio tracks in it."));
 
   Util::setToolTip(ui->cbMDeriveAudioTrackLanguageFromFileName,
@@ -775,6 +790,19 @@ PreferencesDialog::setupMergeAddingAppendingFilesPolicy() {
   ui->cbMAlwaysCreateSettingsForVideoFiles->setChecked(m_cfg.m_mergeAlwaysCreateNewSettingsForVideoFiles);
 }
 
+void
+PreferencesDialog::setupMergeAddingAppendingDirectoriesPolicy() {
+  ui->cbMDragAndDropDirectoriesPolicy->addItem(QY("Always ask the user"),                                             static_cast<int>(Util::Settings::MergeAddingDirectoriesPolicy::Ask));
+  ui->cbMDragAndDropDirectoriesPolicy->addItem(QY("Handle all files from all directories as a single list of files"), static_cast<int>(Util::Settings::MergeAddingDirectoriesPolicy::Flat));
+  ui->cbMDragAndDropDirectoriesPolicy->addItem(QY("Create a new multiplex settings tab for each directory"),          static_cast<int>(Util::Settings::MergeAddingDirectoriesPolicy::AddEachDirectoryToNew));
+
+  Util::setComboBoxIndexIf(ui->cbMDragAndDropDirectoriesPolicy, [this](QString const &, QVariant const &data) {
+    return data.isValid() && (static_cast<Util::Settings::MergeAddingDirectoriesPolicy>(data.toInt()) == m_cfg.m_mergeDragAndDropDirectoriesPolicy);
+  });
+
+  Util::fixComboBoxViewWidth(*ui->cbMDragAndDropDirectoriesPolicy);
+}
+
 void
 PreferencesDialog::setupMergeWarnMissingAudioTrack() {
   ui->cbMWarnMissingAudioTrack->addItem(QY("Never"),                                           static_cast<int>(Util::Settings::MergeMissingAudioTrackPolicy::Never));
@@ -1091,6 +1119,7 @@ PreferencesDialog::save() {
   m_cfg.m_mergeEnableDialogNormGainRemoval                    = ui->cbMEnableDialogNormGainRemoval->isChecked();
   m_cfg.m_mergeAddingAppendingFilesPolicy                     = static_cast<Util::Settings::MergeAddingAppendingFilesPolicy>(ui->cbMAddingAppendingFilesPolicy->currentData().toInt());
   m_cfg.m_mergeDragAndDropFilesPolicy                         = static_cast<Util::Settings::MergeAddingAppendingFilesPolicy>(ui->cbMDragAndDropFilesPolicy->currentData().toInt());
+  m_cfg.m_mergeDragAndDropDirectoriesPolicy                   = static_cast<Util::Settings::MergeAddingDirectoriesPolicy>(ui->cbMDragAndDropDirectoriesPolicy->currentData().toInt());
   m_cfg.m_mergeAlwaysCreateNewSettingsForVideoFiles           = ui->cbMAlwaysCreateSettingsForVideoFiles->isChecked();
   m_cfg.m_mergeSortFilesTracksByTypeWhenAdding                = ui->cbMSortFilesTracksByTypeWhenAdding->isChecked();
   m_cfg.m_mergeReconstructSequencesWhenAdding                 = ui->cbMReconstructSequencesWhenAdding->isChecked();
