@@ -71,6 +71,7 @@ PrefsRunProgramWidget::setupUi(Util::Settings::RunProgramConfig const &cfg) {
 
   p->flagsByCheckbox[p->ui->cbAfterJobQueueStopped] = Util::Settings::RunAfterJobQueueFinishes;
   p->flagsByCheckbox[p->ui->cbAfterJobSuccessful]   = Util::Settings::RunAfterJobCompletesSuccessfully;
+  p->flagsByCheckbox[p->ui->cbAfterJobWarnings]     = Util::Settings::RunAfterJobCompletesWithWarnings;
   p->flagsByCheckbox[p->ui->cbAfterJobError]        = Util::Settings::RunAfterJobCompletesWithErrors;
 
   p->ui->cbConfigurationActive->setChecked(cfg.m_active);
@@ -333,7 +334,7 @@ PrefsRunProgramWidget::changeExecutable() {
 
   enableControls();
 
-  emit titleChanged();
+  Q_EMIT titleChanged();
 }
 
 void
@@ -349,12 +350,12 @@ PrefsRunProgramWidget::commandLineEdited(QString const &commandLine) {
 
   enableControls();
 
-  emit titleChanged();
+  Q_EMIT titleChanged();
 }
 
 void
 PrefsRunProgramWidget::nameEdited() {
-  emit titleChanged();
+  Q_EMIT titleChanged();
 }
 
 void
@@ -390,8 +391,7 @@ PrefsRunProgramWidget::config()
 void
 PrefsRunProgramWidget::changeAudioFile() {
   auto p             = p_func();
-  auto filters       = QStringList{} << QY("Audio files") + Q(" (*.aac *.flac *.m4a *.mp3 *.ogg *.opus *.wav)")
-                                     << QY("All files")   + Q(" (*)");
+  auto filters       = QStringList{} << QY("All files") + Q(" (*)");
 
   auto realAudioFile = Util::replaceMtxVariableWithApplicationDirectory(p->ui->leAudioFile->text());
   auto newAudioFile  = Util::getOpenFileName(this, QY("Select audio file"), realAudioFile, filters.join(Q(";;")));
@@ -404,14 +404,14 @@ PrefsRunProgramWidget::changeAudioFile() {
 
   enableControls();
 
-  emit titleChanged();
+  Q_EMIT titleChanged();
 }
 
 void
 PrefsRunProgramWidget::audioFileEdited() {
   enableControls();
 
-  emit titleChanged();
+  Q_EMIT titleChanged();
 }
 
 void
@@ -421,7 +421,7 @@ PrefsRunProgramWidget::typeChanged(int index) {
 
   showPageForType(type);
 
-  emit titleChanged();
+  Q_EMIT titleChanged();
 
   enableControls();
 }
